@@ -5,8 +5,10 @@
 #' @param ... see \link[dplyr]{group_by}
 #' @return see \link[dplyr]{group_by}
 #' @examples
-#' group_by(mtcars, am, cyl)
+#' mtcars <- group_by(mtcars, am, cyl)
 #' #> group_by: 2 grouping variables (am, cyl)
+#' mtcars <- ungroup(mtcars)
+#' #> ungroup: no grouping variables left
 #' @import dplyr
 #' @export
 group_by <- function(.data, ...) {
@@ -31,14 +33,24 @@ group_by_at <- function(.data, ...) {
     log_group_by(.data, .fun = dplyr::group_by_at, .funname = "group_by_at", ...)
 }
 
+#' @rdname group_by
+#' @export
+ungroup <- function(.data, ...) {
+    log_group_by(.data, .fun = dplyr::ungroup, .funname = "ungroup", ...)
+}
+
 log_group_by <- function(.data, .fun, .funname, ...) {
     newdata <- .fun(.data, ...)
     if (!"data.frame" %in% class(.data) | !should_display()) {
         return(newdata)
     }
     group_vars <- get_groups(newdata)
-    display(glue::glue(
-        "{.funname}: {plural(length(group_vars), 'grouping variable')} ",
-        "({format_list(group_vars)})"))
+    if (is.null(group_vars)) {
+        display(glue::glue("{.funname}: no grouping variables"))
+    } else {
+        display(glue::glue(
+            "{.funname}: {plural(length(group_vars), 'grouping variable')} ",
+            "({format_list(group_vars)})"))
+    }
     newdata
 }
